@@ -367,12 +367,19 @@ about_gnome_cb (GtkWidget *menuitem,
 {
 	GdkScreen *screen = menuitem_to_screen (menuitem);
 
-	if (egg_screen_execute_async (screen, g_get_home_dir (), 1, &program_path) < 0)
+	if (egg_screen_execute_async (screen, g_get_home_dir (), 1, &program_path) < 0) {
+		char *msg;
+		msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s %s",
+			_("Can't execute 'About GNOME'"),
+			_("Details"), program_path,
+			_("probably does not exist"));
+
 		panel_error_dialog (screen,
-				    "cannot_exec_about_gnome",
-				    _("<b>Can't execute 'About GNOME'</b>\n\n"
-				    "Details: %s probably does not exist"),
-				    program_path);
+		                    "cannot_exec_about_gnome",
+		                    msg);
+
+		g_free (msg);
+	}
 }
 
 static void
@@ -391,21 +398,34 @@ activate_app_def (GtkWidget  *menuitem,
 		panel_ditem_launch (
 			item, NULL, 0, menuitem_to_screen (menuitem), &error);
 		if (error) {
+			char *msg;
+			msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s",
+				_("Can't launch entry"),
+				_("Details"), error->message);
+
 			panel_error_dialog (
 				menuitem_to_screen (menuitem),
 				"cant_launch_entry",
-				_("<b>Can't launch entry</b>\n\n"
-				  "Details: %s"), error->message);
+				msg);
+
+			g_free (msg);
 			g_clear_error (&error);
 		}
 		gnome_desktop_item_unref (item);
 	} else {
+		char *msg;
 		g_assert (error != NULL);
+
+		msg = g_strdup_printf ("<b>%s</b>%s: %s",
+			_("Can't load entry"),
+			_("Details"), error->message);
+
 		panel_error_dialog (
 			menuitem_to_screen (menuitem),
 			"cant_load_entry",
-			_("<b>Can't load entry</b>\n\n"
-			  "Details: %s"), error->message);
+			msg);
+
+		g_free (msg);
 		g_clear_error (&error);
 	}
 }
@@ -1098,17 +1118,21 @@ remove_menuitem (GtkWidget *widget, ShowItemMenu *sim)
 	result = gnome_vfs_unlink (sim->item_loc);
 
 	if (result != GNOME_VFS_OK) {
-		char *esc;
+		char *esc, *msg;
 
 		esc = g_markup_escape_text (sim->item_loc, -1);
+		msg = g_strdup_printf ("<b>%s %s</b>\n\n%s: %s\n",
+			_("Could not remove the menu item"),
+			esc,
+			_("Details"),
+			gnome_vfs_result_to_string (result));
 
 		panel_error_dialog (
 			menuitem_to_screen (sim->menuitem),
 			"cant_remove_menu_item",
-			_("<b>Could not remove the menu item %s</b>\n\n"
-			  "Details: %s\n"), 
-			esc,
-			gnome_vfs_result_to_string (result));
+			msg);
+
+		g_free (msg);
 		g_free (esc);
 		return;
 	}
@@ -1188,21 +1212,35 @@ add_to_run_dialog (GtkWidget    *widget,
 
 		if (exec != NULL)
 			panel_run_dialog_present_with_text (menuitem_to_screen (sim->menuitem), exec);
-		else
+		else {
+			char *msg;
+			msg = g_strdup_printf ("<b>%s</b>\n\n%s",
+				_("Can't add to run box"),
+				_("Details: No 'Exec' or 'URL' field in entry"));
+
 			panel_error_dialog (
 				menuitem_to_screen (sim->menuitem),
 				"no_exec_or_url_field",
-				_("<b>Can't add to run box</b>\n\n"
-				  "Details: No 'Exec' or 'URL' field in entry"));
+				msg);
+
+			g_free (msg);
+		}
 
 		gnome_desktop_item_unref (item);
 	} else {
+		char *msg;
 		g_assert (error != NULL);
+
+		msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s",
+			_("Can't load entry"),
+			_("Details"), error->message);
+
 		panel_error_dialog (
 			menuitem_to_screen (sim->menuitem),
 			"cant_load_entry",
-			_("<b>Can't load entry</b>\n\n"
-			  "Details: %s"), error->message);
+			msg);
+
+		g_free (msg);
 		g_clear_error (&error);
 	}
 }
@@ -1224,22 +1262,35 @@ show_help_on (GtkWidget    *widget,
 		const char *docpath = gnome_desktop_item_get_string
 			(item, "X-GNOME-DocPath");
 		if ( ! panel_show_gnome_kde_help (screen, docpath, &error)) {
+			char *msg;
+			msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s",
+				_("Cannot display help document"),
+				_("Details"), error->message);
+
 			panel_error_dialog (
 				screen,
 				"cannot_show_gnome_kde_help",
-				_("<b>Cannot display help document</b>\n\n"
-				  "Details: %s"), error->message);
+				msg);
+
+			g_free (msg);
 			g_clear_error (&error);
 		}
 
 		gnome_desktop_item_unref (item);
 	} else {
+		char *msg;
 		g_assert (error != NULL);
+
+		msg = g_strdup_printf ("<b>%s</b>\n\n%s: %s",
+			_("Can't load entry"),
+			_("Details"), error->message);
+
 		panel_error_dialog (
 			screen,
 			"cant_load_entry",
-			_("<b>Can't load entry</b>\n\n"
-			  "Details: %s"), error->message);
+			msg);
+
+		g_free (msg);
 		g_clear_error (&error);
 	}
 }
